package fi.fa.opplugin;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import kd.bos.dataentity.entity.DynamicObject;
import kd.bos.entity.EntityMetadataCache;
import kd.bos.entity.plugin.AddValidatorsEventArgs;
import kd.bos.entity.plugin.PreparePropertysEventArgs;
import kd.bos.entity.plugin.args.BeginOperationTransactionArgs;
import kd.bos.servicehelper.BusinessDataServiceHelper;
import kd.bos.servicehelper.operation.SaveServiceHelper;
import kd.fi.fa.business.lease.utils.LeaseChangeUtil;
import kd.fi.fa.business.lease.utils.LeaseUtil;
import kd.fi.fa.business.pclock.AbstractPcLockOperationServicePlugIn;
import kd.fi.fa.business.pclock.PcLockConfigBillNoConstants;

public class FaLeaseChangeBillExSubmitOp extends AbstractPcLockOperationServicePlugIn {
    public FaLeaseChangeBillExSubmitOp() {
    }

    public void onPreparePropertys(PreparePropertysEventArgs e) {
        List<String> fieldKeys = e.getFieldKeys();
        fieldKeys.add("billno");
        fieldKeys.add("leasecontract");
        fieldKeys.add("effectivedate");
        fieldKeys.add("changeitems");
        fieldKeys.add("changebakcontract");
    }

    public void onAddValidators(AddValidatorsEventArgs e) {
        DynamicObject aftContract = LeaseChangeUtil.getAftContractForValidate(this.getOption(), e);
        e.addValidator((new FaLeaseChangeBillExSubmitValidator()).buildAftContract(aftContract));
    }

    public void beginOperationTransaction(BeginOperationTransactionArgs e) {
        super.beginOperationTransaction(e);
        LeaseChangeUtil.updateChangeBakContract(this.getOption(), e);
        Map<Long, DynamicObject> changeBakContractMap = this.getAllChangeBakContract(e.getDataEntities());
        DynamicObject[] var3 = e.getDataEntities();
        int var4 = var3.length;

        for(int var5 = 0; var5 < var4; ++var5) {
            DynamicObject bill = var3[var5];
            if (LeaseChangeUtil.isEffectPayPlan(bill)) {
                DynamicObject changeBakContract = bill.getDynamicObject("changebakcontract");
                changeBakContract = (DynamicObject)changeBakContractMap.get(changeBakContract.getLong("id"));
                DynamicObject oriContract = bill.getDynamicObject("leasecontract");
                oriContract = (DynamicObject)changeBakContractMap.get(oriContract.getLong("id"));
                LeaseUtil.generatePayPlan4Chg(changeBakContract, oriContract);
                LeaseUtil.calLeaseContractAmount4Submit(changeBakContract);
            }
        }

        SaveServiceHelper.save((DynamicObject[])changeBakContractMap.values().toArray(new DynamicObject[0]));
    }

    private Map<Long, DynamicObject> getAllChangeBakContract(DynamicObject[] bills) {
        List<Long> changeBakContractIds = new ArrayList(bills.length);
        DynamicObject[] changeBakContractArr = bills;
        int var4 = bills.length;

        for(int var5 = 0; var5 < var4; ++var5) {
            DynamicObject bill = changeBakContractArr[var5];
            DynamicObject changeBakContract = bill.getDynamicObject("changebakcontract");
            changeBakContractIds.add(changeBakContract.getLong("id"));
            DynamicObject oriContract = bill.getDynamicObject("leasecontract");
            changeBakContractIds.add(oriContract.getLong("id"));
        }

        changeBakContractArr = BusinessDataServiceHelper.load(changeBakContractIds.toArray(new Long[0]), EntityMetadataCache.getDataEntityType("fa_lease_contract"));
        return (Map)Arrays.stream(changeBakContractArr).collect(Collectors.toMap((v) -> {
            return v.getLong("id");
        }, (v) -> {
            return v;
        }));
    }

    protected void setPcLockCofig() {
        super.pcLockCofigBillNoList.add(PcLockConfigBillNoConstants.FA_LEASE_CHANGE_DEFAULT_CONFIG);
    }
}
